@@ -1,6 +1,7 @@
-#  Copyright (c) 1997-2018
-#  Ewgenij Gawrilow, Michael Joswig (Technische Universitaet Berlin, Germany)
-#  http://www.polymake.org
+#  Copyright (c) 1997-2021
+#  Ewgenij Gawrilow, Michael Joswig, and the polymake team
+#  Technische Universität Berlin, Germany
+#  https://polymake.org
 #
 #  This program is free software; you can redistribute it and/or modify it
 #  under the terms of the GNU General Public License as published by the
@@ -26,6 +27,13 @@ if (readlink("/proc/self/fd/1") eq "/dev/null") {
 if (readlink("/proc/self/fd/2") eq "/dev/null") {
    push @ARGV, "2>/dev/null";
 }
+
+foreach (@ARGV) {
+   if (/ / && !/^(['"]).+\1$/) {
+      $_="'$_'";
+   }
+}
+
 my $response=Polymake::HostAgent::call("run", @ARGV);
 if ($response =~ /^ERROR/) {
    print STDERR $response;
